#ifndef PWQDIALOG_H
#define PWQDIALOG_H

#include <QDialog>

namespace Ui
{
class PWQDialog;
}

class PWQDialog : public QDialog
{
    Q_OBJECT

public:
    explicit PWQDialog(QWidget *parent = 0);
    ~PWQDialog();

public slots:
    void pwCheck();

private:
    Ui::PWQDialog *ui;
};
#endif // PWQDIALOG_H
